@@ -1,9 +1,21 @@
 from flask import redirect, render_template, request, url_for
 from flask_login import LoginManager, login_required, login_user, logout_user, UserMixin
 
+from Empiric.internal.Print import Print
+
 class Authenticate:
   @staticmethod
-  def init(app, statisticsPassword):
+  def _validPassword(password):
+    return password is not None and len(password) > 5
+  @staticmethod
+  def init(app, password):
+    if password is None:
+      Print.log('No password for the statistics website provided. The')
+      Print.log2('page will be disabled.')
+    elif not Authenticate._validPassword(password):
+      Print.logWarning('The password for the statistics websites needs to be')
+      Print.log2Warning('six characters in length at the minimum. The page will')
+      Print.log2Warning('be disabled.')
     app.config.update(SECRET_KEY='Empiric!', USE_SESSION_FOR_NEXT=True)
     loginManager = LoginManager()
     loginManager.init_app(app)
@@ -17,7 +29,7 @@ class Authenticate:
     @app.route('/login', methods=['GET', 'POST'])
     def login():
       if request.method == 'POST':
-        if 'password' in request.form and request.form['password'] == statisticsPassword:
+        if 'password' in request.form and Authenticate._validPassword(password) and request.form['password'] == password:
           login_user(User(defaultUser))
           return redirect(url_for('statistics'))
         else:
